==> moodle-1.5-mysql.tgz: moodle/lang/tr/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5 ALPHA (2005043000)


$string['asset'] = 'Varlk';
$string['attr_error'] = '$a->tag etiketinde ($a->attr) zellii iin hatal deer.';
$string['autocontinue'] = 'Otomatik Devam Et';
$string['badmanifest'] = 'Manifest hatas: hata loglarna bakn';
$string['browse'] = 'Gzat';
$string['browsed'] = 'Gzatld';
$string['browsemode'] = 'Gezinme Modu';
$string['chooseapacket'] = 'Se veya SCORM paketi ykle';
$string['completed'] = 'Tamamland';
$string['coursepacket'] = 'Kurs paketi';
$string['coursestruct'] = 'Ders Yaps';
$string['datadir'] = 'Dosya sistemi hatas: Kurs veri klasr oluturulamad.';
$string['details'] = 'Pyl.r.Nesn. izleme detaylar';
$string['display'] = 'Grnm';
$string['domxml'] = 'DOMXML harici ktphanesi';
$string['enablebrowse'] = 'nizleme modunu etkinletir';
$string['entercourse'] = 'SCORM Paketine giri';
$string['errorlogs'] = 'Hata logu';
$string['exit'] = 'SCORM Paketinden k';
$string['expcoll'] = 'Genilet/Daralt';
$string['failed'] = 'Hata olutu';
$string['found'] = 'Manifest bulundu';
$string['frameheight'] = 'Bu seenek SCO erevesinin varsaylan geniliini ayarlar';
$string['framewidth'] = 'Bu seenek SCO erevesinin varsaylan yksekliini ayarlar';
$string['gradeaverage'] = 'Ortalama not';
$string['gradehighest'] = 'En yksek not';
$string['grademethod'] = 'Not verme yntemi';
$string['gradescoes'] = 'Pyl.r.Nesn durumu';
$string['gradesum'] = 'Notlar topla';
$string['guestsno'] = 'Konuk kullanclar SCORM derslerini gremezler';
$string['height'] = 'Ykseklik';
$string['incomplete'] = 'Tamamlanmad';
$string['missing_attribute'] = '$a->tag etiketi iinde hatal $a->attr zellii';
$string['missing_tag'] = 'Hatal tag $a->tag';
$string['mode'] = 'Mod';
$string['modulename'] = 'Scorm';
$string['modulenameplural'] = 'Scormlar';
$string['next'] = 'Sonraki';
$string['no_attributes'] = '$a->tag etiketinin zellikleri olmal';
$string['no_children'] = '$a->tag etiketinin yavrular olmal';
$string['nomanifest'] = 'Manifest bulunamad';
$string['noreports'] = 'Gsterilecek rapor yok';
$string['normal'] = 'Normal';
$string['not_corr_type'] = '$a->tag etiketi iin tip uyumsuzluu';
$string['notattempted'] = 'Uygulanmad';
$string['organizations'] = 'Dzenlemeler';
$string['packagedir'] = 'Dosya sistemi hatas: Klasr oluturulamyor';
$string['passed'] = 'Geti';
$string['php5'] = 'PHP 5 (DOMXML doal ktphansesi)';
$string['popup'] = 'u anki nesneyi yeni bir pencerede a';
$string['position_error'] = '$a->tag etiketi, $a->parent etiketinin yavrusu olamaz.';
$string['prev'] = 'nceki';
$string['regular'] = 'Dzenli Manifest';
$string['report'] = 'Rapor';
$string['review'] = 'nizleme';
$string['scoes'] = 'Paylalabilir ierik nesneleri';
$string['score'] = 'Puan';
$string['syntax'] = 'Yazm hatas';
$string['tag_error'] = 'Bu ierikte bilinmeyen bir etiket ($a->tag) var: $a->value';
$string['too_many_attributes'] = '$a->tag etiketinin ok fazla zellii var';
$string['too_many_children'] = '$a->tag etiketinin ok fazla yavrusu var';
$string['trackingloose'] = 'UYARI: Bu SCORM paketinin izleme verileri kaybedilecek.';
$string['validateascorm'] = 'Bir SCORM paketi denetle';
$string['validation'] = 'Dorulama sonucu';
$string['validationtype'] = 'Bu seenek SCORM paketindeki manifest dosyasnnn geerliliini dorulamak iin DOMXML ktphanesinin kullanmn ayarlar. Ne yaptnz bilmiyorsanz seili seenei brakn.';
$string['versionwarning'] = 'Manifest srm 1.3 den daha eski, $a->tag etiketinde uyar';
$string['viewallreports'] = 'Toplam $a uygulama raporu var';
$string['width'] = 'Genilik';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/tr/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5 + (2005060201)


$string['advanced'] = 'Gelimi';
$string['asset'] = 'Varlk';
$string['attr_error'] = '$a->tag etiketinde ($a->attr) zellii iin hatal deer.';
$string['autocontinue'] = 'Otomatik Devam Et';
$string['badmanifest'] = 'Manifest hatas: hata kaytlarna bakn';
$string['browse'] = 'Gzat';
$string['browsed'] = 'Gzatld';
$string['browsemode'] = 'Gezinme Modu';
$string['chooseapacket'] = 'Se veya bir paketi gncelle';
$string['completed'] = 'Tamamland';
$string['coursepacket'] = 'Kurs paketi';
$string['coursestruct'] = 'Ders Yaps';
$string['datadir'] = 'Dosya sistemi hatas: Kurs veri klasr oluturulamad.';
$string['details'] = 'Pyl.r.Nesn. izleme detaylar';
$string['display'] = 'Grnm';
$string['domxml'] = 'DOMXML harici ktphanesi';
$string['enablebrowse'] = 'nizleme modunu etkinletir';
$string['entercourse'] = 'Kursa gir';
$string['errorlogs'] = 'Hata kaytlar';
$string['exit'] = 'SCORM kursundan k';
$string['expcoll'] = 'Genilet/Daralt';
$string['failed'] = 'Hata olutu';
$string['firstaccess'] = 'lk eriim';
$string['found'] = 'Manifest bulundu';
$string['frameheight'] = 'Bu seenek SCO erevesinin varsaylan yksekliini ayarlar';
$string['framewidth'] = 'Bu seenek SCO erevesinin varsaylan geniliini ayarlar';
$string['gradeaverage'] = 'Ortalama not';
$string['gradehighest'] = 'En yksek not';
$string['grademethod'] = 'Not verme yntemi';
$string['gradescoes'] = 'Pyl.r.Nesn durumu';
$string['gradesum'] = 'Notlar topla';
$string['guestsno'] = 'Konuk kullanclar SCORM kurslarna eriemezler';
$string['height'] = 'Ykseklik';
$string['incomplete'] = 'Tamamlanmad';
$string['lastaccess'] = 'Son eriim';
$string['missing_attribute'] = '$a->tag etiketi iinde hatal $a->attr zellii';
$string['missing_tag'] = 'Hatal tag $a->tag';
$string['mode'] = 'Mod';
$string['modulename'] = 'Scorm';
$string['modulenameplural'] = 'Scormlar';
$string['next'] = 'Sonraki';
$string['no_attributes'] = '$a->tag etiketinin zellikleri olmal';
$string['no_children'] = '$a->tag etiketinin yavrular olmal';
$string['noactivity'] = 'Rapor edilecek bir ey yok';
$string['nomanifest'] = 'Manifest bulunamad';
$string['noreports'] = 'Gsterilecek rapor yok';
$string['normal'] = 'Normal';
$string['not_corr_type'] = '$a->tag etiketi iin tip uyumsuzluu';
$string['notattempted'] = 'Uygulanmad';
$string['organization'] = 'Dzenleme';
$string['organizations'] = 'Dzenlemeler';
$string['packagedir'] = 'Dosya sistemi hatas: Klasr oluturulamyor';
$string['packagefile'] = 'Paket dosya belirtilmedi';
$string['passed'] = 'Geti';
$string['php5'] = 'PHP 5 (DOMXML doal ktphansesi)';
$string['popup'] = 'renme Nesnelerini yeni pencerede a';
$string['position_error'] = '$a->tag etiketi, $a->parent etiketinin yavrusu olamaz.';
$string['prev'] = 'nceki';
$string['regular'] = 'Dzenli Manifest';
$string['report'] = 'Rapor';
$string['review'] = 'nizleme';
$string['scoes'] = 'Paylalabilir ierik nesneleri';
$string['score'] = 'Puan';
$string['scormcourse'] = 'SCORM Kursu';
$string['stagesize'] = 'ereve/Pencere boyutu';
$string['syntax'] = 'Yazm hatas';
$string['tag_error'] = 'Bu ierikte bilinmeyen bir etiket ($a->tag) var: $a->value';
$string['too_many_attributes'] = '$a->tag etiketinin ok fazla zellii var';
$string['too_many_children'] = '$a->tag etiketinin ok fazla yavrusu var';
$string['totaltime'] = 'Zaman';
$string['trackingloose'] = 'UYARI: Bu SCORM paketinin izleme verileri kaybedilecek.';
$string['validateascorm'] = 'Bir paket denetle';
$string['validation'] = 'Dorulama sonucu';
$string['validationtype'] = 'Bu seenek SCORM paketindeki manifest dosyasnnn geerliliini dorulamak iin DOMXML ktphanesinin kullanmn ayarlar. Ne yaptnz bilmiyorsanz seili olan brakn.';
$string['versionwarning'] = 'Manifest srm 1.3\'den daha eski, $a->tag etiketinde uyar';
$string['viewallreports'] = 'Toplam $a uygulama raporu var';
$string['width'] = 'Genilik';

?>
